#!/bin/csh
#SBATCH -N 1
#SBATCH -n 1
#SBATCH --cpus-per-task 20
#SBATCH --job-name=name-here  
#SBATCH -t 00:15:00
#SBATCH -p debug
# ASSUMPTION (1): input files are named   dynXX.inp   where XX is optional
#  useful for startup phase; for example, to start using dynstrt.inp,
#    dyn.csh strt
#  would be used; for production dynamics runs, simply dyn.csh
# ASSUMPTION (2): output files are named    dyn.res  dyn.trj  dyn.out
# ASSUMPTION (3): previous restart file read as  dyn.rea
#

setenv CONV_RSH ssh
unset noclobber

#This if statement was coded by Robert Allsopp and swaps the input colective variables for ABF calculation
#This is like a switch turning on ABF then turning off ABF and turning on pulling for 1 A, then repeat until the histogram is complete
#Then to work in decimals the .csh doesn't input such numbers
#need to count up from zero 
#then for center: internally do the math: divide by 10 and subtract from 16
#For targetcenter: internally do the math: divide by 10 and subtract from 15.9 

#if ( { grep -q 'step5_input.colvar_pulling_abf.str' dyn.inp } ) then
#sed 's/step5_input.colvar_pulling_abf.str/step5_input.colvar_pulling.str/' dyn_test.inp >> dyn_test.inp
#create a tracking file that stores the centers for the simulation
@ center = `cat center `
set center = `expr $center + 1 `
echo $center
echo $center > center
@ targetcenter = `cat targetcenter `
set targetcenter = `expr $targetcenter + 1 `
echo $targetcenter
echo $targetcenter > targetcenter



#set center = `expr $center/10 - 15.1`

#set targetcenter = `expr $targetcenter/4 - 15`
set center = `echo "$center/4 -15.25" | bc -l`
set targetcenter = `echo "$targetcenter/4 - 15" | bc -l`



rm dyn_test*.inp
#only need to use these if the peptide unfolds during the pulling
#echo "constraints             on" >> dyn_test.inp
#echo "consexp                 2" >> dyn_test.inp
#echo "consref                 restraints/constraints.ref" >> dyn_test.inp
#echo "conskfile               restraints/constraints.ref" >> dyn_test.inp
#echo "conskcol                B" >> dyn_test.inp
#echo "constraintScaling       250" >> dyn_test.inp

echo "# planar and Pulling restraint" >> dyn_test.inp
echo "exec sed -e "s/Constant \\\$fc/Constant 90/g" step5_input.colvar_pulling.str > dyn_pull_1.col" >> dyn_test.inp
echo "exec sed -e "s/centers \\\$c/centers $center/g" dyn_pull_1.col > dyn_pull_2.col" >> dyn_test.inp
echo "exec sed -e "s/Centers \\\$tc/Centers $targetcenter/g" dyn_pull_2.col > dyn_pull_3.col" >> dyn_test.inp
echo "colvars                 on" >> dyn_test.inp
echo "colvarsConfig           dyn_pull_3.col" >> dyn_test.inp

echo "run 10000 ;" >> dyn_test.inp

sed 's/-e s/-e "s/g' dyn_test.inp >> dyn_test_2.inp
sed 's/g d/g" d/g' dyn_test_2.inp >> dyn_test_3.inp
sed 's/g s/g" s/g' dyn_test_3.inp >> dyn_test_4.inp


#else
#sed 's/step5_input.colvar_pulling.str/step5_input.colvar_pulling_abf.str/' dyn_test.inp >> dyn_test.inp
#rm dyn_test*.inp
#@ targetcenter = `cat targetcenter `
#set targetcenter = `echo "$targetcenter/4 - 15" | bc -l`
#echo $targetcenter
#echo "# planar and Pulling restraint" >> dyn_test.inp
#echo "exec sed -e "s/Constant \\\$fc/Constant 90/g" step5_input.colvar_pulling_abf.str > dyn_abf_1.col" >> dyn_test.inp
#echo "exec sed -e "s/centers \\\$c/centers $targetcenter/g" dyn_abf_1.col > dyn_abf_2.col" >> dyn_test.inp
#echo "colvars                 on" >> dyn_test.inp
#echo "colvarsConfig           dyn_abf_2.col" >> dyn_test.inp
#
#echo "run 10000 ;" >> dyn_test.inp
#
##it starts off with pulling so set it to abf so it will switch it to pulling then it will increment so adjust the Centers and target centers to be -1 each to start properly
##then it will switch to pulling and the target center will become the new center so I can just swap the variable 
##then the next time it runs it will be abf again and everything should increment properly
#
#sed 's/-e s/-e "s/g' dyn_test.inp >> dyn_test_2.inp
#sed 's/g d/g" d/g' dyn_test_2.inp >> dyn_test_3.inp
#sed 's/g s/g" s/g' dyn_test_3.inp >> dyn_test_4.inp
#
#
#endif




# Set Run Length per file
set simt = 10000

echo Running on host `hostname`
echo Time is `date`
echo Directory is `pwd`
echo This jobs runs on the following processors:

cd $SLURM_SUBMIT_DIR
echo $SLURM_SUBMIT_DIR
pwd


@ krun = 1

if ( -e start.time) then
 @ start = `cat start.time `
else
 @ start = 0                  
endif

module load namd

# Create a new input file
rm -f dyn.inp
cat dyn-1.inp > dyn.inp
echo "firsttimestep     $start; " >> dyn.inp
cat dyn-2.inp >> dyn.inp
cat dyn_test_4.inp >> dyn.inp



set one = one
echo $one > test.file
echo $one
# Execution of the script
charmrun namd2 +p 19 +ppn 19 +setcpuaffinity dyn.inp >& dyn.out

echo $one >> test.file
echo $one

set okay = true
# TEST FOR EXISTENCE, THEN NONZERO LENGTH OF OUTPUT FILES
if ( -e dyn.coor && -e dyn.dcd ) then
 @ tsz = `/bin/ls -s dyn.dcd | awk '{print $1}'`
 @ nrm = `grep 'WallClock' dyn.out | wc -l`
 @ nrm1 = `grep 'ERROR: ' dyn.out | wc -l`
 
echo $tsz >> test.file
echo $tsz
echo $nrm >> test.file
echo $nrm
 if ( $tsz > 0 && $nrm == 1 && $nrm1 < 1 ) then
# SUCCESSFUL RUN; COPY RESTART FILE
#  cp dyn.res dyn.rea
# DETERMINE RUN NUMBER
  if ( -e next.seqno ) then
   @ i = `cat next.seqno` 
  else
   @ i = 1
  endif
# Change the new Start Time
@ start = $start + $simt
echo $start > start.time

# ENABLE/DISABLE ANALYSIS EVERY 2ND RUN
#  if ( 0 == $i % 2 ) qsub -l nodes=1 chk.csh
# NUMBER THE OUTPUT FILES; CHANGE EXTENSIONS TO SUIT APPLICATION
  foreach fil ( out coor xsc xst vel dcd pmf grad czar.pmf czar.grad count zcount zgrad colvars.traj )
   mv dyn.$fil dyn$i.$fil
  end
  cp dyn$i.xsc dyn.xsc
  cp dyn$i.coor dyn.coor
  cp dyn$i.vel dyn.vel
  gzip dyn$i.out dyn$i.coor dyn$i.xsc dyn$i.vel dyn$i.xst
# CONDITIONAL END CHECK
  if ( -e last.seqno ) then
    @ l = `cat last.seqno`
    if ( $i == $l ) then
      @ i += 1
      echo $i > next.seqno 
      exit
    endif
  endif

# SUBMIT THE NEXT JOB
#  rm ~/namd.$PBS_JOBID
  sleep 30 s
  @ i += 1
  echo $i > next.seqno
  ./dyn.scr
  exit
else
# FILE DOESN'T EXIST
 set okay = false
endif
# FILE DOESN'T EXIST
 set okay = false
endif

# TEST FOR CHARMM RUN FAILED; CREATE .ERR FILE WITH TIMESTAMP
if ( $okay == false ) then
 set ts = `date +%m%d.%H%M`
 mv dyn.out dyn.err.$ts
 exit(201)
endif

end

